Name:           plocate
Version:        1.1.23
Release:        %mkrel 2
Summary:        Much faster locate
Group:          File tools
License:        GPLv2+
URL:            https://plocate.sesse.net/
Source0:        https://plocate.sesse.net/download/plocate-%{version}.tar.gz
Source1:        plocate.sysusers
Source10:       updatedb.conf
BuildRequires:  meson
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(liburing)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  libatomic

# The plan is to provide both mlocate and plocate for one or two
# Fedora releases, and then retire mlocate when the bugs in plocate
# have been ironed out. Thus, we only allow one or the other to be
# installed.
Conflicts:      mlocate
Provides:       locate

# https://bugzilla.redhat.com/show_bug.cgi?id=2052433
Obsoletes:      mlocate < 0.26-16

# Filesystem providing /var/lib/rpm-state
Requires:       filesystem >= 2.1.9-36

Requires(post):  rpm-helper
Requires(preun): rpm-helper

%description
plocate is a locate(1) based on posting lists, giving much faster
searches on a much smaller index. It is a drop-in replacement for
mlocate in nearly all aspects, and is fast on SSDs and non-SSDs alike.

%prep
%autosetup -p1

%build
%meson -Dsystemunitdir=%{_unitdir} -Dinstall_systemd=true
%meson_build

# Man page alias
cat >locate.1 <<EOF
.so man1/plocate.1
EOF

%install
%meson_install

install -p -D -m 0644 %{SOURCE1} %{buildroot}%{_sysusersdir}/plocate.conf
ln -s plocate %{buildroot}%{_bindir}/locate
install -p -D -m 0644 -t %{buildroot}%{_mandir}/man1/ locate.1

install -D -p -m 0644 %{SOURCE10} %{buildroot}%{_sysconfdir}/updatedb.conf

mkdir -p %{buildroot}%{_sharedstatedir}/plocate/
touch %{buildroot}%{_sharedstatedir}/plocate/plocate.db

# A state file to carry information from %%post to %%posttrans. See
# https://docs.fedoraproject.org/en-US/packaging-guidelines/Scriptlets/#_saving_state_between_scriptlets.
%global plocate_start_now %{_localstatedir}/lib/rpm-state/plocate_start_now

%pre
#sysusers_create_compat %{SOURCE1}
%sysusers_create_package %name %{SOURCE1}

%post
%create_ghostfile %{_sharedstatedir}/plocate/plocate.db root plocate 0640
%_post_service plocate-updatedb

if [ $1 == 1 ] && [ -d /run/systemd ]; then
     touch %{plocate_start_now} || :
fi

%preun
%_preun_service plocate-updatedb

%posttrans
# The timer runs once per day. On new installs, let's start both the
# timer and the service immediately in the background, so that the db
# becomes populated. When people install this package onto a running
# system, it's reasonable to assume that they want to use the database.
if [ -f %{plocate_start_now} ]; then
   rm %{plocate_start_now} || :
   if systemctl is-enabled plocate-updatedb.timer &>/dev/null; then
      systemctl start --no-block plocate-updatedb.timer plocate-updatedb.service || :
   fi
fi

%files
%license COPYING
%doc README
%attr(02755,-,plocate) %{_bindir}/plocate
%{_bindir}/locate
%{_sbindir}/plocate-build
%{_sbindir}/updatedb
%{_unitdir}/plocate-updatedb.service
%{_unitdir}/plocate-updatedb.timer
%{_mandir}/man1/plocate.1*
%{_mandir}/man1/locate.1*
%{_mandir}/man5/updatedb.conf.5*
%{_mandir}/man8/plocate-build.8*
%{_mandir}/man8/updatedb.8*
%{_sysusersdir}/plocate.conf
%config(noreplace) %{_sysconfdir}/updatedb.conf
%dir %{_sharedstatedir}/plocate
%{_sharedstatedir}/plocate/CACHEDIR.TAG
%ghost %attr(0640,-,plocate) %verify(not md5 mtime) %{_sharedstatedir}/plocate/plocate.db


%changelog
* Mon Jun 30 2025 umeabot <umeabot> 1.1.23-2.mga10
+ Revision: 2230866
- Mageia 10 Mass Rebuild

* Wed Dec 04 2024 daviddavid <daviddavid> 1.1.23-1.mga10
+ Revision: 2121538
- new version: 1.1.23

* Fri Nov 29 2024 daviddavid <daviddavid> 1.1.22-1.mga10
+ Revision: 2119970
- new version: 1.1.22
+ wally <wally>
- add /var/lib/flatpak to PRUNEPATHS

* Sat Jun 10 2023 ghibo <ghibo> 1.1.19-1.mga9
+ Revision: 1961602
- Update to release 1.1.19

* Mon Jun 05 2023 daviddavid <daviddavid> 1.1.17-2.mga9
+ Revision: 1961035
- convert to use our systemd service macros

* Thu Dec 29 2022 luigiwalser <luigiwalser> 1.1.17-1.mga9
+ Revision: 1927848
- 1.1.17

* Mon Sep 19 2022 luigiwalser <luigiwalser> 1.1.16-1.mga9
+ Revision: 1890677
- 1.1.16
- update updatedb.conf with enhancements from debian via fedora

* Tue Sep 06 2022 wally <wally> 1.1.15-3.mga9
+ Revision: 1884599
- require filesystem shipping /var/lib/rpm-state
- add /var/lib/mock/ to PRUNEPATHS in default updatedb.conf

* Tue Sep 06 2022 wally <wally> 1.1.15-2.mga9
+ Revision: 1884578
- use default updatedb.conf from mlocate
- create db file during %%post

* Wed Aug 17 2022 tv <tv> 1.1.15-1.mga9
+ Revision: 1878355
- imported package plocate


* Wed Aug 17 2022 Thierry Vignaud <tv@mageia.org> 1.1.15-1.mga9
- Import from FC.
- plocate is a better alternative to mlocate which it replaced in Debian & Fedoar
  It's much faster than mlocate & uses less disk space

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> 1.1.15-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Sun Mar 06 2022 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> 1.1.15-3
- Add Obsoletes for mlocate versions in F35- (for #2052433)

* Sat Feb 19 2022 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> 1.1.15-2
- Add virtual Provides:locate to make upgrades easier (rhbz#2052433)

* Sat Feb 19 2022 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> 1.1.15-1
- Version 1.1.15

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> 1.1.13-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Nov 26 2021 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> 1.1.13-4
- Fix mode in %%ghost line

* Wed Nov 24 2021 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> 1.1.13-3
- Add %%ghost for /etc/updatedb.conf

* Wed Nov 24 2021 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> 1.1.13-2
- Add locate(1) man page alias

* Wed Nov 24 2021 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> 1.1.13-1
- Version 1.1.13

* Fri Oct 29 2021 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> 1.1.12-2
- Remove plocate.db when the package is removed

* Fri Oct 29 2021 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> 1.1.12-1
- Version 1.1.12

* Wed Sep 08 2021 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> 1.1.11-1
- Version 1.1.11

* Mon Jun 21 2021 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.1.8-1
- Update to latest version

* Wed May 12 2021 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.1.7-1
- Resolve comments from initial review
- Start the service and timer in %%posttrans
- Conflict with mlocate and provide /bin/locate alias

* Fri Feb 19 2021 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 1.1.4-1
- First version

